@@ -42,6 +42,7 @@ Afrikaan_LO_full
    <ja>LibreOffice 用のアフリカーンス語のメタパッケージ</ja>
    <kk>Afrikaans Language Meta-Package for LibreOffice</kk>
    <ko>Afrikaans Language Meta-Package for LibreOffice</ko>
+   <ku>Afrikaans Language Meta-Package for LibreOffice</ku>
    <lt>Afrikaans Language Meta-Package for LibreOffice</lt>
    <mk>Afrikaans Language Meta-Package for LibreOffice</mk>
    <mr>Afrikaans Language Meta-Package for LibreOffice</mr>
@@ -49,6 +50,7 @@ Afrikaan_LO_full
    <nb>Afrikaans språkpakke for LibreOffice</nb>
    <nl_BE>Afrikaans Language Meta-Package for LibreOffice</nl_BE>
    <nl>Afrikaans Taal Meta-Pakket voor LibreOffice</nl>
+   <or>Afrikaans Language Meta-Package for LibreOffice</or>
    <pl>Meta-pakiet języka Afrikaans dla LibreOffice</pl>
    <pt_BR>Africâner Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Meta-Pacote de Idioma Africander para o LibreOffice</pt>
@@ -56,6 +58,7 @@ Afrikaan_LO_full
    <ru>Afrikaans Language Meta-Package for LibreOffice</ru>
    <sk>Afrikaans Language Meta-Package for LibreOffice</sk>
    <sl>Afrikaan jezikovni meta-paket za LibreOffice</sl>
+   <so>Afrikaans Language Meta-Package for LibreOffice</so>
    <sq>Meta-Paketë gjuhësore për LibreOffice-in në afrikaans</sq>
    <sr>Afrikaans Language Meta-Package for LibreOffice</sr>
    <sv>Afrikaans Språk Meta-Paket för LibreOffice</sv>
