@@ -42,6 +42,7 @@ Arabic_LO_Latest_main
    <ja>LibreOffice用のアラビア語メタパッケージ</ja>
    <kk>Arabic Language Meta-Package for LibreOffice</kk>
    <ko>Arabic Language Meta-Package for LibreOffice</ko>
+   <ku>Arabic Language Meta-Package for LibreOffice</ku>
    <lt>Arabic Language Meta-Package for LibreOffice</lt>
    <mk>Arabic Language Meta-Package for LibreOffice</mk>
    <mr>Arabic Language Meta-Package for LibreOffice</mr>
@@ -49,6 +50,7 @@ Arabic_LO_Latest_main
    <nb>Arabisk språkpakke for LibreOffice</nb>
    <nl_BE>Arabic Language Meta-Package for LibreOffice</nl_BE>
    <nl>Arabische Taal Meta-Pakket voor LibreOffice​</nl>
+   <or>Arabic Language Meta-Package for LibreOffice</or>
    <pl>Arabski meta-pakiet językowy dla LibreOffice</pl>
    <pt_BR>Árabe Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Árabe Meta-Pacote de Idioma para LibreOffice</pt>
@@ -56,6 +58,7 @@ Arabic_LO_Latest_main
    <ru>Arabic Language Meta-Package for LibreOffice</ru>
    <sk>Arabic Language Meta-Package for LibreOffice</sk>
    <sl>Arabski jezikovni meta-paket za LibreOffice</sl>
+   <so>Arabic Language Meta-Package for LibreOffice</so>
    <sq>Meta-Paketë gjuhësore për LibreOffice-in në arabisht</sq>
    <sr>Arabic Language Meta-Package for LibreOffice</sr>
    <sv>Arabiskt Språk Meta-Paket för LibreOffice</sv>
