@@ -42,6 +42,7 @@ Bulgarian_Firefox
    <ja>ブルガリア語版 Firefox</ja>
    <kk>Bulgarian localisation of Firefox</kk>
    <ko>Bulgarian localisation of Firefox</ko>
+   <ku>Bulgarian localisation of Firefox</ku>
    <lt>Bulgarian localisation of Firefox</lt>
    <mk>Bulgarian localisation of Firefox</mk>
    <mr>Bulgarian localisation of Firefox</mr>
@@ -49,6 +50,7 @@ Bulgarian_Firefox
    <nb>Bulgarsk lokaltilpassing av Firefox</nb>
    <nl_BE>Bulgarian localisation of Firefox</nl_BE>
    <nl>Bulgaarse lokalisatie van Firefox</nl>
+   <or>Bulgarian localisation of Firefox</or>
    <pl>Bułgarska lokalizacja przeglądarki Firefox</pl>
    <pt_BR>Búlgaro Localização para o Firefox</pt_BR>
    <pt>Búlgaro Localização para Firefox</pt>
@@ -56,6 +58,7 @@ Bulgarian_Firefox
    <ru>Болгарская локализация Firefox</ru>
    <sk>Bulgarian localisation of Firefox</sk>
    <sl>Bulgarian localisation of Firefox</sl>
+   <so>Bulgarian localisation of Firefox</so>
    <sq>Përkthimi i Firefox-it në bullgarisht</sq>
    <sr>Bulgarian localisation of Firefox</sr>
    <sv>Bulgarisk lokalisering av  Firefox</sv>
