@@ -42,6 +42,7 @@ Bulgarian_LO_Latest_main
    <ja>LibreOffice 用ブルガリア語メタパッケージ</ja>
    <kk>Bulgarian Language Meta-Package for LibreOffice</kk>
    <ko>Bulgarian Language Meta-Package for LibreOffice</ko>
+   <ku>Bulgarian Language Meta-Package for LibreOffice</ku>
    <lt>Bulgarian Language Meta-Package for LibreOffice</lt>
    <mk>Bulgarian Language Meta-Package for LibreOffice</mk>
    <mr>Bulgarian Language Meta-Package for LibreOffice</mr>
@@ -49,6 +50,7 @@ Bulgarian_LO_Latest_main
    <nb>Bulgarsk språkpakke for LibreOffice</nb>
    <nl_BE>Bulgarian Language Meta-Package for LibreOffice</nl_BE>
    <nl>Bulgaars Taal Meta-Pakket voor LibreOffice</nl>
+   <or>Bulgarian Language Meta-Package for LibreOffice</or>
    <pl>Bułgarski meta-pakiet językowy dla LibreOffice</pl>
    <pt_BR>Búlgaro Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Búlgaro Meta-Pacote de Idioma para LibreOffice</pt>
@@ -56,6 +58,7 @@ Bulgarian_LO_Latest_main
    <ru>Bulgarian Language Meta-Package for LibreOffice</ru>
    <sk>Bulgarian Language Meta-Package for LibreOffice</sk>
    <sl>Bolgarski jezikovni meta-paket za LibreOffice</sl>
+   <so>Bulgarian Language Meta-Package for LibreOffice</so>
    <sq>Meta-Paketë gjuhësore për LibreOffice-in në bullgarisht</sq>
    <sr>Bulgarian Language Meta-Package for LibreOffice</sr>
    <sv>Bulgariskt Språk Meta-Paket för LibreOffice</sv>
