@@ -42,6 +42,7 @@ Catalan_LO_Latest_main
    <ja>カタロニア語用 LibreOffice 言語メタパッケージ</ja>
    <kk>Catalan LibreOffice Language Meta-Package</kk>
    <ko>Catalan LibreOffice Language Meta-Package</ko>
+   <ku>Catalan LibreOffice Language Meta-Package</ku>
    <lt>Catalan LibreOffice Language Meta-Package</lt>
    <mk>Catalan LibreOffice Language Meta-Package</mk>
    <mr>Catalan LibreOffice Language Meta-Package</mr>
@@ -49,6 +50,7 @@ Catalan_LO_Latest_main
    <nb>Katalansk språkpakke for LibreOffice</nb>
    <nl_BE>Catalan LibreOffice Language Meta-Package</nl_BE>
    <nl>Catalaanse LibreOffice Taal Meta-Pakket</nl>
+   <or>Catalan LibreOffice Language Meta-Package</or>
    <pl>Kataloński metapakiet językowy dla LibreOffice</pl>
    <pt_BR>Catalão Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Catalão Meta-Pacote de Idioma para LibreOffice</pt>
@@ -56,6 +58,7 @@ Catalan_LO_Latest_main
    <ru>Catalan LibreOffice Language Meta-Package</ru>
    <sk>Catalan LibreOffice Language Meta-Package</sk>
    <sl>Katalonski jezikovni metapaket za LibreOffice</sl>
+   <so>Catalan LibreOffice Language Meta-Package</so>
    <sq>Meta-Paketë gjuhësore për LibreOffice-in në katalanisht</sq>
    <sr>Catalan LibreOffice Language Meta-Package</sr>
    <sv>Katalansk LibreOffice Språk-Meta-Paket</sv>
