@@ -42,6 +42,7 @@ Chinese_TW_LO_Latest_main
    <ja>LibreOffice の繁体字中国語版</ja>
    <kk>Chinese_traditional localisation of LibreOffice</kk>
    <ko>Chinese_traditional localisation of LibreOffice</ko>
+   <ku>Chinese_traditional localisation of LibreOffice</ku>
    <lt>Chinese_traditional localisation of LibreOffice</lt>
    <mk>Chinese_traditional localisation of LibreOffice</mk>
    <mr>Chinese_traditional localisation of LibreOffice</mr>
@@ -49,6 +50,7 @@ Chinese_TW_LO_Latest_main
    <nb>Kinesisk (tradisjonell) lokaltilpassing av LibreOffice</nb>
    <nl_BE>Chinese_traditional localisation of LibreOffice</nl_BE>
    <nl>Traditioneel Chinese lokalisatie van LibreOffice</nl>
+   <or>Chinese_traditional localisation of LibreOffice</or>
    <pl>Chiński tradycyjny lokalizacja LibreOffice</pl>
    <pt_BR>Chinês Tradicional Localização para o LibreOffice</pt_BR>
    <pt>Chinês_tradicional Localização para LibreOffice</pt>
@@ -56,6 +58,7 @@ Chinese_TW_LO_Latest_main
    <ru>Chinese_traditional localisation of LibreOffice</ru>
    <sk>Chinese_traditional localisation of LibreOffice</sk>
    <sl>Kitajske (tradicionalno) krajevne nastavitve za LibreOffice</sl>
+   <so>Chinese_traditional localisation of LibreOffice</so>
    <sq>Përkthimi i LibreOffice-it në kinezçe tradicionale</sq>
    <sr>Chinese_traditional localisation of LibreOffice</sr>
    <sv>Kinesisk_traditionell lokalisering av LibreOffice</sv>
