@@ -42,6 +42,7 @@ Dzongkha_LO_main
    <ja>LibreOffice用のゾンカ語メタパッケージ</ja>
    <kk>Dzongkha Language Meta-Package for LibreOffice</kk>
    <ko>Dzongkha Language Meta-Package for LibreOffice</ko>
+   <ku>Dzongkha Language Meta-Package for LibreOffice</ku>
    <lt>Dzongkha Language Meta-Package for LibreOffice</lt>
    <mk>Dzongkha Language Meta-Package for LibreOffice</mk>
    <mr>Dzongkha Language Meta-Package for LibreOffice</mr>
@@ -49,6 +50,7 @@ Dzongkha_LO_main
    <nb>Dzongkha språkpakke for LibreOffice</nb>
    <nl_BE>Dzongkha Language Meta-Package for LibreOffice</nl_BE>
    <nl>Dzongkha Taal Meta-Pakket voor LibreOffice</nl>
+   <or>Dzongkha Language Meta-Package for LibreOffice</or>
    <pl>Meta-pakiet języka Dzongkha dla LibreOffice</pl>
    <pt_BR>Butanês Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Dzonga Meta-Pacote de Idioma para LibreOffice</pt>
@@ -56,6 +58,7 @@ Dzongkha_LO_main
    <ru>Dzongkha Language Meta-Package for LibreOffice</ru>
    <sk>Dzongkha Language Meta-Package for LibreOffice</sk>
    <sl>Dzongha jezikovni meta-paket za LibreOffice</sl>
+   <so>Dzongkha Language Meta-Package for LibreOffice</so>
    <sq>Meta-Paketë gjuhësore për LibreOffice-in në xonga</sq>
    <sr>Dzongkha Language Meta-Package for LibreOffice</sr>
    <sv>Dzongkha Språk Meta-Paket för LibreOffice</sv>
