@@ -42,6 +42,7 @@ Estonian_LO_Latest_main
    <ja>LibreOffice用エストニア語メタパッケージ</ja>
    <kk>Estonian Language Meta-Package for LibreOffice</kk>
    <ko>Estonian Language Meta-Package for LibreOffice</ko>
+   <ku>Estonian Language Meta-Package for LibreOffice</ku>
    <lt>Estonian Language Meta-Package for LibreOffice</lt>
    <mk>Estonian Language Meta-Package for LibreOffice</mk>
    <mr>Estonian Language Meta-Package for LibreOffice</mr>
@@ -49,6 +50,7 @@ Estonian_LO_Latest_main
    <nb>Estisk språkpakke for LibreOffice</nb>
    <nl_BE>Estonian Language Meta-Package for LibreOffice</nl_BE>
    <nl>Estoons Taal Meta-Pakket voor LibreOffice</nl>
+   <or>Estonian Language Meta-Package for LibreOffice</or>
    <pl>Estoński meta-pakiet językowy dla LibreOffice</pl>
    <pt_BR>Estónio Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Estónio Meta-Pacote de Idioma para LibreOffice</pt>
@@ -56,6 +58,7 @@ Estonian_LO_Latest_main
    <ru>Estonian Language Meta-Package for LibreOffice</ru>
    <sk>Estonian Language Meta-Package for LibreOffice</sk>
    <sl>Estonski jezikovni meta-paket za LibreOffice</sl>
+   <so>Estonian Language Meta-Package for LibreOffice</so>
    <sq>Meta-Paketë gjuhësore për LibreOffice-in në estonisht</sq>
    <sr>Estonian Language Meta-Package for LibreOffice</sr>
    <sv>Estniskt Språk Meta-Paket för LibreOffice</sv>
