@@ -42,6 +42,7 @@ French_Firefox
    <ja>Firefox のフランス語版</ja>
    <kk>French localisation of Firefox</kk>
    <ko>French localisation of Firefox</ko>
+   <ku>French localisation of Firefox</ku>
    <lt>French localisation of Firefox</lt>
    <mk>French localisation of Firefox</mk>
    <mr>French localisation of Firefox</mr>
@@ -49,6 +50,7 @@ French_Firefox
    <nb>Fransk lokaltilpassing av Firefox</nb>
    <nl_BE>French localisation of Firefox</nl_BE>
    <nl>Franse lokalisatie van Firefox</nl>
+   <or>French localisation of Firefox</or>
    <pl>Francuska lokalizacja przeglądarki Firefox</pl>
    <pt_BR>Francês Localização para o Firefox</pt_BR>
    <pt>Francês Localização para Firefox</pt>
@@ -56,6 +58,7 @@ French_Firefox
    <ru>Французская локализация Firefox</ru>
    <sk>French localisation of Firefox</sk>
    <sl>Francoske krajevne nastavitve za Firefox</sl>
+   <so>French localisation of Firefox</so>
    <sq>Përkthimi i Firefox-it në frëngjisht</sq>
    <sr>French localisation of Firefox</sr>
    <sv>Fransk lokalisering av Firefox</sv>
