@@ -42,6 +42,7 @@ Hindi_LO_main
    <ja>LibreOffice 用のヒンディー語メタパッケージ</ja>
    <kk>Hindi Language Meta-Package for LibreOffice</kk>
    <ko>Hindi Language Meta-Package for LibreOffice</ko>
+   <ku>Hindi Language Meta-Package for LibreOffice</ku>
    <lt>Hindi Language Meta-Package for LibreOffice</lt>
    <mk>Hindi Language Meta-Package for LibreOffice</mk>
    <mr>Hindi Language Meta-Package for LibreOffice</mr>
@@ -49,6 +50,7 @@ Hindi_LO_main
    <nb>Hindi språkpakke for LibreOffice</nb>
    <nl_BE>Hindi Language Meta-Package for LibreOffice</nl_BE>
    <nl>Hindi Taal Meta-Pakket voor LibreOffice</nl>
+   <or>Hindi Language Meta-Package for LibreOffice</or>
    <pl>Meta-pakiet języka Hindi dla LibreOffice</pl>
    <pt_BR>Hindi Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Hindi Meta-Pacote de Idioma para LibreOffice</pt>
@@ -56,6 +58,7 @@ Hindi_LO_main
    <ru>Hindi Language Meta-Package for LibreOffice</ru>
    <sk>Hindi Language Meta-Package for LibreOffice</sk>
    <sl>Hindujski jezikovni meta-paket za LibreOffice</sl>
+   <so>Hindi Language Meta-Package for LibreOffice</so>
    <sq>Përkthimi i Firefox-it ESR në Hinduisht (Indi)</sq>
    <sr>Hindi Language Meta-Package for LibreOffice</sr>
    <sv>Hindi Språk Meta-Paket för LibreOffice</sv>
