@@ -42,6 +42,7 @@ Indonesian_LO_Latest_main
    <ja>LibreOffice用のインドネシア語メタパッケージ</ja>
    <kk>Indonesian Language Meta-Package for LibreOffice</kk>
    <ko>Indonesian Language Meta-Package for LibreOffice</ko>
+   <ku>Indonesian Language Meta-Package for LibreOffice</ku>
    <lt>Indonesian Language Meta-Package for LibreOffice</lt>
    <mk>Indonesian Language Meta-Package for LibreOffice</mk>
    <mr>Indonesian Language Meta-Package for LibreOffice</mr>
@@ -49,6 +50,7 @@ Indonesian_LO_Latest_main
    <nb>Indonesisk språkpakke for LibreOffice</nb>
    <nl_BE>Indonesian Language Meta-Package for LibreOffice</nl_BE>
    <nl>Indonesisch Taal Meta-Pakket voor LibreOffice</nl>
+   <or>Indonesian Language Meta-Package for LibreOffice</or>
    <pl>Indonezyjski meta-pakiet językowy dla LibreOffice</pl>
    <pt_BR>Indonésio Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Indonésio Meta-Pacote de Idioma para LibreOffice</pt>
@@ -56,6 +58,7 @@ Indonesian_LO_Latest_main
    <ru>Indonesian Language Meta-Package for LibreOffice</ru>
    <sk>Indonesian Language Meta-Package for LibreOffice</sk>
    <sl>Indonezijski jezikovni meta-paket za LibreOffice</sl>
+   <so>Indonesian Language Meta-Package for LibreOffice</so>
    <sq>Meta-Paketë gjuhësore për LibreOffice-in në indonezisht</sq>
    <sr>Indonesian Language Meta-Package for LibreOffice</sr>
    <sv>Indonesiskt Språk Meta-Paket för LibreOffice</sv>
