@@ -42,6 +42,7 @@ Kinarwanda_LO_Latest_full
    <ja>LibreOffice 用ルワンダ言語メタパッケージ</ja>
    <kk>Kinarwanda Language Meta-Package for LibreOffice</kk>
    <ko>Kinarwanda Language Meta-Package for LibreOffice</ko>
+   <ku>Kinarwanda Language Meta-Package for LibreOffice</ku>
    <lt>Kinarwanda Language Meta-Package for LibreOffice</lt>
    <mk>Kinarwanda Language Meta-Package for LibreOffice</mk>
    <mr>Kinarwanda Language Meta-Package for LibreOffice</mr>
@@ -49,6 +50,7 @@ Kinarwanda_LO_Latest_full
    <nb>Kinarwanda språkpakke for LibreOffice</nb>
    <nl_BE>Kinarwanda Language Meta-Package for LibreOffice</nl_BE>
    <nl>Kinarwanda Taal Meta-Pakket voor LibreOffice</nl>
+   <or>Kinarwanda Language Meta-Package for LibreOffice</or>
    <pl>Meta-pakiet języka Kinarwanda dla LibreOffice</pl>
    <pt_BR>Quiniaruanda Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Kinarwanda Meta-Pacote de Idioma para LibreOffice</pt>
@@ -56,6 +58,7 @@ Kinarwanda_LO_Latest_full
    <ru>Kinarwanda Language Meta-Package for LibreOffice</ru>
    <sk>Kinarwanda Language Meta-Package for LibreOffice</sk>
    <sl>Kinarvandski jezikovni meta-paket za LibreOffice</sl>
+   <so>Kinarwanda Language Meta-Package for LibreOffice</so>
    <sq>Meta-Paketë gjuhësore për LibreOffice-in në kinaruandisht</sq>
    <sr>Kinarwanda Language Meta-Package for LibreOffice</sr>
    <sv>Kinarwanda Språk Meta-Paket för LibreOffice</sv>
