@@ -42,6 +42,7 @@ Ligurian_Default_Firefox_esr
    <ja>リグリア語版 Firefox ESR</ja>
    <kk>Ligurian localisation of Firefox ESR</kk>
    <ko>Ligurian localisation of Firefox ESR</ko>
+   <ku>Ligurian localisation of Firefox ESR</ku>
    <lt>Ligurian localisation of Firefox ESR</lt>
    <mk>Ligurian localisation of Firefox ESR</mk>
    <mr>Ligurian localisation of Firefox ESR</mr>
@@ -49,6 +50,7 @@ Ligurian_Default_Firefox_esr
    <nb>Ligursk lokaltilpassing av Firefox ESR</nb>
    <nl_BE>Ligurian localisation of Firefox ESR</nl_BE>
    <nl>Ligurian localisation of Firefox ESR</nl>
+   <or>Ligurian localisation of Firefox ESR</or>
    <pl>Ligurian localisation of Firefox ESR</pl>
    <pt_BR>Ligúria Localização para o Firefox ESR</pt_BR>
    <pt>Ligúrio Localização para Firefox ESR</pt>
@@ -56,6 +58,7 @@ Ligurian_Default_Firefox_esr
    <ru>Ligurian localisation of Firefox ESR</ru>
    <sk>Ligurian localisation of Firefox ESR</sk>
    <sl>Ligurijske krajevne nastavitve za Firefox ESR</sl>
+   <so>Ligurian localisation of Firefox ESR</so>
    <sq>Përkthimi i Firefox-it ESR në ligure</sq>
    <sr>Ligurian localisation of Firefox ESR</sr>
    <sv>Ligurisk lokalisering av Firefox ESR</sv>
