@@ -42,6 +42,7 @@ Lithuanian_Firefox
    <ja>Firefox のリトアニア語版</ja>
    <kk>Lithuanian localisation of Firefox</kk>
    <ko>Lithuanian localisation of Firefox</ko>
+   <ku>Lithuanian localisation of Firefox</ku>
    <lt>Lithuanian localisation of Firefox</lt>
    <mk>Lithuanian localisation of Firefox</mk>
    <mr>Lithuanian localisation of Firefox</mr>
@@ -49,6 +50,7 @@ Lithuanian_Firefox
    <nb>Litauisk lokaltilpassing av Firefox</nb>
    <nl_BE>Lithuanian localisation of Firefox</nl_BE>
    <nl>Litouwse lokalisatie van Firefox</nl>
+   <or>Lithuanian localisation of Firefox</or>
    <pl>Litewska lokalizacja przeglądarki Firefox</pl>
    <pt_BR>Lituano Localização para o Firefox</pt_BR>
    <pt>Lituano Localização para Firefox</pt>
@@ -56,6 +58,7 @@ Lithuanian_Firefox
    <ru>Литовская локализация Firefox</ru>
    <sk>Lithuanian localisation of Firefox</sk>
    <sl>Litvanske krajevne nastavitve za Firefox</sl>
+   <so>Lithuanian localisation of Firefox</so>
    <sq>Përkthimi i Firefox-it në lituanisht</sq>
    <sr>Lithuanian localisation of Firefox</sr>
    <sv>Litauisk lokalisering av Firefox</sv>
