@@ -42,6 +42,7 @@ Macedonian_LO_Latest_main
    <ja>LibreOffice用のマケドニア語メタパッケージ</ja>
    <kk>Macedonian Language Meta-Package for LibreOffice</kk>
    <ko>Macedonian Language Meta-Package for LibreOffice</ko>
+   <ku>Macedonian Language Meta-Package for LibreOffice</ku>
    <lt>Macedonian Language Meta-Package for LibreOffice</lt>
    <mk>Macedonian Language Meta-Package for LibreOffice</mk>
    <mr>Macedonian Language Meta-Package for LibreOffice</mr>
@@ -49,6 +50,7 @@ Macedonian_LO_Latest_main
    <nb>Makedonsk språkpakke for LibreOffice</nb>
    <nl_BE>Macedonian Language Meta-Package for LibreOffice</nl_BE>
    <nl>Macedonisch Taal Meta-Pakket voor LibreOffice</nl>
+   <or>Macedonian Language Meta-Package for LibreOffice</or>
    <pl>Meta-pakiet języka macedońskiego dla LibreOffice</pl>
    <pt_BR>Macedônio Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Macedónio Meta-Pacote de Idioma para LibreOffice</pt>
@@ -56,6 +58,7 @@ Macedonian_LO_Latest_main
    <ru>Macedonian Language Meta-Package for LibreOffice</ru>
    <sk>Macedonian Language Meta-Package for LibreOffice</sk>
    <sl>Makedonski jezikovni meta-paket za LibreOffice</sl>
+   <so>Macedonian Language Meta-Package for LibreOffice</so>
    <sq>Meta-Paketë gjuhësore për LibreOffice-in në maqedonisht</sq>
    <sr>Macedonian Language Meta-Package for LibreOffice</sr>
    <sv>Macedoniskt Språk Meta-Paket för LibreOffice</sv>
