@@ -42,6 +42,7 @@ North Sámi
    <ja>Hunspell 用北サーミ語辞書</ja>
    <kk>North Sámi dictionary for hunspell</kk>
    <ko>North Sámi dictionary for hunspell</ko>
+   <ku>North Sámi dictionary for hunspell</ku>
    <lt>North Sámi dictionary for hunspell</lt>
    <mk>North Sámi dictionary for hunspell</mk>
    <mr>North Sámi dictionary for hunspell</mr>
@@ -49,6 +50,7 @@ North Sámi
    <nb>Nordsamisk ordliste for hunspell</nb>
    <nl_BE>North Sámi dictionary for hunspell</nl_BE>
    <nl>North Sámi dictionary for hunspell</nl>
+   <or>North Sámi dictionary for hunspell</or>
    <pl>North Sámi dictionary for hunspell</pl>
    <pt_BR>Dicionário Sámi do Norte para o hunspell (corretor ortográfico e analisador morfológico)</pt_BR>
    <pt>Dicionário Sámi do Norte para hunspell</pt>
@@ -56,6 +58,7 @@ North Sámi
    <ru>North Sámi dictionary for hunspell</ru>
    <sk>North Sámi dictionary for hunspell</sk>
    <sl>Severni Sami slovar za hunspell</sl>
+   <so>North Sámi dictionary for hunspell</so>
    <sq>Fjalor samishte veriore për hunspell</sq>
    <sr>North Sámi dictionary for hunspell</sr>
    <sv>Nordsamisk ordbok för hunspell</sv>
