@@ -42,6 +42,7 @@ Norwegian_LO_Latest_full
    <ja>LibreOffice用のノルウェー語メタパッケージ</ja>
    <kk>Norwegian Language Meta-Package for LibreOffice</kk>
    <ko>Norwegian Language Meta-Package for LibreOffice</ko>
+   <ku>Norwegian Language Meta-Package for LibreOffice</ku>
    <lt>Norwegian Language Meta-Package for LibreOffice</lt>
    <mk>Norwegian Language Meta-Package for LibreOffice</mk>
    <mr>Norwegian Language Meta-Package for LibreOffice</mr>
@@ -49,6 +50,7 @@ Norwegian_LO_Latest_full
    <nb>Norsk bokmålsk språkpakke for LibreOffice</nb>
    <nl_BE>Norwegian Language Meta-Package for LibreOffice</nl_BE>
    <nl>Noorse Taal Meta-Pakket voor LibreOffice</nl>
+   <or>Norwegian Language Meta-Package for LibreOffice</or>
    <pl>Norweski metapakiet językowy dla LibreOffice</pl>
    <pt_BR>Norueguês Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Norueguês Meta-Pacote de Idioma para LibreOffice</pt>
@@ -56,6 +58,7 @@ Norwegian_LO_Latest_full
    <ru>Norwegian Language Meta-Package for LibreOffice</ru>
    <sk>Norwegian Language Meta-Package for LibreOffice</sk>
    <sl>Norveški jezikovni meta-paket za LibreOffice</sl>
+   <so>Norwegian Language Meta-Package for LibreOffice</so>
    <sq>Meta-Paketë gjuhësore për LibreOffice-in në norvegjisht</sq>
    <sr>Norwegian Language Meta-Package for LibreOffice</sr>
    <sv>Norskt Språk Meta-Paket för LibreOffice</sv>
