@@ -42,6 +42,7 @@ Occitan
    <ja>Hunspell 用オック語辞書</ja>
    <kk>Occitan dictionary for hunspell</kk>
    <ko>Occitan dictionary for hunspell</ko>
+   <ku>Occitan dictionary for hunspell</ku>
    <lt>Occitan dictionary for hunspell</lt>
    <mk>Occitan dictionary for hunspell</mk>
    <mr>Occitan dictionary for hunspell</mr>
@@ -49,6 +50,7 @@ Occitan
    <nb>Occitansk ordliste for hunspell</nb>
    <nl_BE>Occitan dictionary for hunspell</nl_BE>
    <nl>Occitan dictionary for hunspell</nl>
+   <or>Occitan dictionary for hunspell</or>
    <pl>Occitan dictionary for hunspell</pl>
    <pt_BR>Dicionário Occitana para o hunspell (corretor ortográfico e analisador morfológico)</pt_BR>
    <pt>Dicionário Occitano para hunspell</pt>
@@ -56,6 +58,7 @@ Occitan
    <ru>Occitan dictionary for hunspell</ru>
    <sk>Occitan dictionary for hunspell</sk>
    <sl>Okitanski slovar za hunspell</sl>
+   <so>Occitan dictionary for hunspell</so>
    <sq>Fjalor oçitanisht për hunspell</sq>
    <sr>Occitan dictionary for hunspell</sr>
    <sv>Occitansk ordbok för hunspell</sv>
