@@ -42,6 +42,7 @@ SSotho_LO_main
    <ja>LibreOffice用の南ソト語メタパッケージ</ja>
    <kk>Southern_sotho Language Meta-Package for LibreOffice</kk>
    <ko>Southern_sotho Language Meta-Package for LibreOffice</ko>
+   <ku>Southern_sotho Language Meta-Package for LibreOffice</ku>
    <lt>Southern_sotho Language Meta-Package for LibreOffice</lt>
    <mk>Southern_sotho Language Meta-Package for LibreOffice</mk>
    <mr>Southern_sotho Language Meta-Package for LibreOffice</mr>
@@ -49,6 +50,7 @@ SSotho_LO_main
    <nb>Sørsotho språkpakke for LibreOffice</nb>
    <nl_BE>Southern_sotho Language Meta-Package for LibreOffice</nl_BE>
    <nl>Zuid-sotho Taal Meta-Pakket voor LibreOffice</nl>
+   <or>Southern_sotho Language Meta-Package for LibreOffice</or>
    <pl>Meta-pakiet języka Southern_sotho dla LibreOffice</pl>
    <pt_BR>Sesoto Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Sotho meridional Meta-Pacote de Idioma para LibreOffice</pt>
@@ -56,6 +58,7 @@ SSotho_LO_main
    <ru>Southern_sotho Language Meta-Package for LibreOffice</ru>
    <sk>Southern_sotho Language Meta-Package for LibreOffice</sk>
    <sl>Južno-sotski jezikovni meta-paket za LibreOffice</sl>
+   <so>Southern_sotho Language Meta-Package for LibreOffice</so>
    <sq>Meta-Paketë gjuhësore për LibreOffice-in në soto jugore</sq>
    <sr>Southern_sotho Language Meta-Package for LibreOffice</sr>
    <sv>Southern_sotho Språk Meta-Paket för LibreOffice</sv>
