@@ -42,6 +42,7 @@ Tamil_LO_full
    <ja>LibreOffice用のタミル語メタパッケージ</ja>
    <kk>Tamil Language Meta-Package for LibreOffice</kk>
    <ko>Tamil Language Meta-Package for LibreOffice</ko>
+   <ku>Tamil Language Meta-Package for LibreOffice</ku>
    <lt>Tamil Language Meta-Package for LibreOffice</lt>
    <mk>Tamil Language Meta-Package for LibreOffice</mk>
    <mr>Tamil Language Meta-Package for LibreOffice</mr>
@@ -49,6 +50,7 @@ Tamil_LO_full
    <nb>Tamil språkpakke for LibreOffice</nb>
    <nl_BE>Tamil Language Meta-Package for LibreOffice</nl_BE>
    <nl>Tamilse Taal Meta-Pakket voor LibreOffice</nl>
+   <or>Tamil Language Meta-Package for LibreOffice</or>
    <pl>Tamilski meta-pakiet językowy dla LibreOffice</pl>
    <pt_BR>Tamil Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Tamil Meta-Pacote de Idioma para LibreOffice</pt>
@@ -56,6 +58,7 @@ Tamil_LO_full
    <ru>Tamil Language Meta-Package for LibreOffice</ru>
    <sk>Tamil Language Meta-Package for LibreOffice</sk>
    <sl>Tamilski jezikovni meta-paket za LibreOffice</sl>
+   <so>Tamil Language Meta-Package for LibreOffice</so>
    <sq>Meta-Paketë gjuhësore për LibreOffice-in në tamile</sq>
    <sr>Tamil Language Meta-Package for LibreOffice</sr>
    <sv>Tamil Språk Meta-Paket för LibreOffice</sv>
