@@ -42,6 +42,7 @@ Tswana_LO_Latest_full
    <ja>LibreOffice用のツワナ語メタパッケージ</ja>
    <kk>Tswana Language Meta-Package for LibreOffice</kk>
    <ko>Tswana Language Meta-Package for LibreOffice</ko>
+   <ku>Tswana Language Meta-Package for LibreOffice</ku>
    <lt>Tswana Language Meta-Package for LibreOffice</lt>
    <mk>Tswana Language Meta-Package for LibreOffice</mk>
    <mr>Tswana Language Meta-Package for LibreOffice</mr>
@@ -49,6 +50,7 @@ Tswana_LO_Latest_full
    <nb>Tswana språkpakke for LibreOffice</nb>
    <nl_BE>Tswana Language Meta-Package for LibreOffice</nl_BE>
    <nl>Tswana Taal Meta-Pakket voor LibreOffice</nl>
+   <or>Tswana Language Meta-Package for LibreOffice</or>
    <pl>Tswana meta-pakiet językowy dla LibreOffice</pl>
    <pt_BR>Tswana Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Tswana Meta-Pacote de Idioma para LibreOffice</pt>
@@ -56,6 +58,7 @@ Tswana_LO_Latest_full
    <ru>Tswana Language Meta-Package for LibreOffice</ru>
    <sk>Tswana Language Meta-Package for LibreOffice</sk>
    <sl>Tswanski jezikovni meta-paket za LibreOffice</sl>
+   <so>Tswana Language Meta-Package for LibreOffice</so>
    <sq>Meta-Paketë gjuhësore për LibreOffice-in në cuana</sq>
    <sr>Tswana Language Meta-Package for LibreOffice</sr>
    <sv>Tswana Språk Meta-Paket för LibreOffice</sv>
