@@ -42,6 +42,7 @@ Winehq-staging
    <ja>Windows のコピーなしで Windows アプリケーションを実行します</ja>
    <kk>run Windows applications without a copy of Microsoft Windows</kk>
    <ko>run Windows applications without a copy of Microsoft Windows</ko>
+   <ku>run Windows applications without a copy of Microsoft Windows</ku>
    <lt>run Windows applications without a copy of Microsoft Windows</lt>
    <mk>run Windows applications without a copy of Microsoft Windows</mk>
    <mr>run Windows applications without a copy of Microsoft Windows</mr>
@@ -49,6 +50,7 @@ Winehq-staging
    <nb>kjør Windows-programmer uten å ha Microsoft Windows installert</nb>
    <nl_BE>run Windows applications without a copy of Microsoft Windows</nl_BE>
    <nl>Windowstoepassingen uitvoeren zonder een exemplaar van Microsoft Windows</nl>
+   <or>run Windows applications without a copy of Microsoft Windows</or>
    <pl>uruchamiaj aplikacje Windows bez kopii systemu Microsoft Windows</pl>
    <pt_BR>Executa aplicativos para Windows sem precisar de uma cópia do Microsoft Windows</pt_BR>
    <pt>Executar aplicações para Windows sem precisar do Microsoft Windows</pt>
@@ -56,6 +58,7 @@ Winehq-staging
    <ru>Запуск приложений для Windows в окружении GNU/Linux</ru>
    <sk>run Windows applications without a copy of Microsoft Windows</sk>
    <sl>Poženite Windows aplikacije brez kopije Microsoft Windows</sl>
+   <so>run Windows applications without a copy of Microsoft Windows</so>
    <sq>Xhironi aplikacione Windows pa një kopje të Microsoft Windows-it</sq>
    <sr>run Windows applications without a copy of Microsoft Windows</sr>
    <sv>kör Windows applikationer utan Microsoft Windows</sv>
