@@ -42,6 +42,7 @@ KeepassX
    <ja>KeePassX はフリーでオープンソースのパスワードマネージャー兼金庫です</ja>
    <kk>KeePassX is a free/open-source password manager/safe</kk>
    <ko>KeePassX is a free/open-source password manager/safe</ko>
+   <ku>KeePassX is a free/open-source password manager/safe</ku>
    <lt>KeePassX is a free/open-source password manager/safe</lt>
    <mk>KeePassX is a free/open-source password manager/safe</mk>
    <mr>KeePassX is a free/open-source password manager/safe</mr>
@@ -49,6 +50,7 @@ KeepassX
    <nb>KeePassX lagrer passord på en sikker måte</nb>
    <nl_BE>KeePassX is a free/open-source password manager/safe</nl_BE>
    <nl>KeePassX is een gratis/open-source wachtwoord manager/kluis</nl>
+   <or>KeePassX is a free/open-source password manager/safe</or>
    <pl>KeePassX to bezpłatny menedżer haseł/sejf o otwartym kodzie źródłowym</pl>
    <pt_BR>KeePassX - Gerenciador de senhas seguro livre/de código aberto</pt_BR>
    <pt>Guarda e gestão de senhas (palavras-passe) em software livre e de fonte aberta</pt>
@@ -56,6 +58,7 @@ KeepassX
    <ru>KeePassX - менеджер паролей с открытым кодом (форк KeePass)</ru>
    <sk>KeePassX is a free/open-source password manager/safe</sk>
    <sl>KeePassXje brezplačen odprtokodni urejevalnik/sef za gesla</sl>
+   <so>KeePassX is a free/open-source password manager/safe</so>
    <sq>KeePassX është një përgjegjës/kasafortë i lirë/me burim të hapur fjalëkalimesh</sq>
    <sr>KeePassX is a free/open-source password manager/safe</sr>
    <sv>KeePassX är en fri/öppen källkod lösenordshanterare/förvarare</sv>
