@@ -42,6 +42,7 @@ ModemManager
    <ja>モバイルブロードバンド（2G/3G/4G）デバイスと接続の制御</ja>
    <kk>Controls mobile broadband (2G/3G/4G) devices and connections</kk>
    <ko>Controls mobile broadband (2G/3G/4G) devices and connections</ko>
+   <ku>Controls mobile broadband (2G/3G/4G) devices and connections</ku>
    <lt>Controls mobile broadband (2G/3G/4G) devices and connections</lt>
    <mk>Controls mobile broadband (2G/3G/4G) devices and connections</mk>
    <mr>Controls mobile broadband (2G/3G/4G) devices and connections</mr>
@@ -49,6 +50,7 @@ ModemManager
    <nb>Styrer enheter for mobilt bredbånd (2G/3G/4G) og tilkoblinger</nb>
    <nl_BE>Controls mobile broadband (2G/3G/4G) devices and connections</nl_BE>
    <nl>Controls mobile broadband (2G/3G/4G) devices and connections</nl>
+   <or>Controls mobile broadband (2G/3G/4G) devices and connections</or>
    <pl>Controls mobile broadband (2G/3G/4G) devices and connections</pl>
    <pt_BR>Controle de dispositivos e conexões de banda larga móvel (2G/3G/4G)</pt_BR>
    <pt>Controla dispositivos e ligações móveis (2G/3G/4G)</pt>
@@ -56,6 +58,7 @@ ModemManager
    <ru>Controls mobile broadband (2G/3G/4G) devices and connections</ru>
    <sk>Controls mobile broadband (2G/3G/4G) devices and connections</sk>
    <sl>Nadzor and mobilnimi širokopoasovnimi napravami (2G/3G/4G) in povezavami</sl>
+   <so>Controls mobile broadband (2G/3G/4G) devices and connections</so>
    <sq>Kontrollon pajisje dhe lidhje celulare (2G/3G/4G)</sq>
    <sr>Controls mobile broadband (2G/3G/4G) devices and connections</sr>
    <sv>Kontrollerar mobila bredbands (2G/3G/4G) enheter och anslutningar</sv>
