@@ -42,6 +42,7 @@ SuperTuxKart
    <ja>マリオカート風のレースゲーム</ja>
    <kk>Mario kart style racing</kk>
    <ko>Mario kart style racing</ko>
+   <ku>Mario kart style racing</ku>
    <lt>Mario kart style racing</lt>
    <mk>Mario kart style racing</mk>
    <mr>Mario kart style racing</mr>
@@ -49,6 +50,7 @@ SuperTuxKart
    <nb>Super Mario Kart-lignende kappkjøring</nb>
    <nl_BE>Mario kart style racing</nl_BE>
    <nl>Mario kart stijl racen</nl>
+   <or>Mario kart style racing</or>
    <pl>wyścigi w stylu Mario Kart</pl>
    <pt_BR>Jogo de vídeo de corridas de carte, estilo o jogo Mario Kart</pt_BR>
    <pt>Jogo de vídeo de corridas de karts, do tipo Mario kart</pt>
@@ -56,6 +58,7 @@ SuperTuxKart
    <ru>Гонки на картах в стиле Mario</ru>
    <sk>Mario kart style racing</sk>
    <sl>Mario kartingu podobna  igra</sl>
+   <so>Mario kart style racing</so>
    <sq>Gara me makina kart në stil Mario</sq>
    <sr>Mario kart style racing</sr>
    <sv>Mario kart stil racing</sv>
