@@ -42,6 +42,7 @@ Waterfox Classic
    <ja>モジラベースの代替ブラウザー</ja>
    <kk>alternative mozilla-based browser</kk>
    <ko>alternative mozilla-based browser</ko>
+   <ku>alternative mozilla-based browser</ku>
    <lt>alternative mozilla-based browser</lt>
    <mk>alternative mozilla-based browser</mk>
    <mr>alternative mozilla-based browser</mr>
@@ -49,6 +50,7 @@ Waterfox Classic
    <nb>alternativ Mozilla-basert nettleser</nb>
    <nl_BE>alternative mozilla-based browser</nl_BE>
    <nl>alternatieve op mozilla gebaseerde browser</nl>
+   <or>alternative mozilla-based browser</or>
    <pl>alternatywna przeglądarka oparta na Mozilli</pl>
    <pt_BR>Waterfox - Navegador de internet baseado no código do Mozilla</pt_BR>
    <pt>Navegador web alternativo baseado no firefox da Mozilla</pt>
@@ -56,6 +58,7 @@ Waterfox Classic
    <ru>Браузер основанный на Firefox (сохранена поддержка дополнений на XUL/XPCOM)</ru>
    <sk>alternative mozilla-based browser</sk>
    <sl>Alternativni brskalnik, ki temelji na Mozilli</sl>
+   <so>alternative mozilla-based browser</so>
    <sq>Shfletues alternativ, bazuar në mozilla</sq>
    <sr>alternative mozilla-based browser</sr>
    <sv>alternativ mozilla-baserad webbläsare</sv>
